Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1063)

Unified Diff: net/base/network_change_notifier_win.h

Issue 9147026: API for connection type (Ethernet/WIFI/WWAN ...) in NetworkChangeNotifier. (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Fixed a typo Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/base/network_change_notifier_mac.cc ('k') | net/base/network_change_notifier_win.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/base/network_change_notifier_win.h
diff --git a/net/base/network_change_notifier_win.h b/net/base/network_change_notifier_win.h
index d8c9a457787b92838c0d4ae21b447597fb048d31..d37cb8f55c8387cafa04f82e9cc1c13d3cff0aa8 100644
--- a/net/base/network_change_notifier_win.h
+++ b/net/base/network_change_notifier_win.h
@@ -52,7 +52,7 @@ class NET_EXPORT_PRIVATE NetworkChangeNotifierWin
friend class NetworkChangeNotifierWinTest;
// NetworkChangeNotifier methods:
- virtual bool IsCurrentlyOffline() const OVERRIDE;
+ virtual ConnectionType GetCurrentConnectionType() const OVERRIDE;
// ObjectWatcher::Delegate methods:
// Must only be called on the thread |this| was created on.
@@ -63,8 +63,8 @@ class NET_EXPORT_PRIVATE NetworkChangeNotifierWin
// thread |this| was created on.
void NotifyObservers();
- // Forwards online state notifications to parent class.
- void NotifyParentOfOnlineStateChange();
+ // Forwards connection type notifications to parent class.
+ void NotifyParentOfConnectionTypeChange();
// Tries to start listening for a single subsequent address change. Returns
// false on failure. The caller is responsible for updating |is_watching_|.
« no previous file with comments | « net/base/network_change_notifier_mac.cc ('k') | net/base/network_change_notifier_win.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698